summaryrefslogtreecommitdiffstats
path: root/kppp/providerdb.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit2bc1d72869b62af05ae4feafd878203b526da8c5 (patch)
tree2676903bb600bd9646644856e354940471ad84e2 /kppp/providerdb.cpp
parent937b2991d8e78166eea904c80ad04d34607017a4 (diff)
downloadtdenetwork-2bc1d72869b62af05ae4feafd878203b526da8c5.tar.gz
tdenetwork-2bc1d72869b62af05ae4feafd878203b526da8c5.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdenetwork@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kppp/providerdb.cpp')
-rw-r--r--kppp/providerdb.cpp18
1 files changed, 9 insertions, 9 deletions
diff --git a/kppp/providerdb.cpp b/kppp/providerdb.cpp
index f27c5528..97d13612 100644
--- a/kppp/providerdb.cpp
+++ b/kppp/providerdb.cpp
@@ -48,8 +48,8 @@
TQWizard* ProviderDB::wiz = 0L;
-ProviderDB::ProviderDB(TQWidget *tqparent) :
- KWizard(tqparent, "", true),
+ProviderDB::ProviderDB(TQWidget *parent) :
+ KWizard(parent, "", true),
cfg(0)
{
setCaption(i18n("Create New Account"));
@@ -164,7 +164,7 @@ void ProviderDB::accept() {
/////////////////////////////////////////////////////////////////////////////
//
/////////////////////////////////////////////////////////////////////////////
-PDB_Intro::PDB_Intro(TQWidget *tqparent) : TQWidget(tqparent) {
+PDB_Intro::PDB_Intro(TQWidget *parent) : TQWidget(parent) {
TQLabel *l = new TQLabel(i18n("You will be asked a few questions on information\n"
"which is needed to establish an Internet connection\n"
"with your Internet Service Provider (ISP).\n\n"
@@ -182,7 +182,7 @@ PDB_Intro::PDB_Intro(TQWidget *tqparent) : TQWidget(tqparent) {
/////////////////////////////////////////////////////////////////////////////
//
/////////////////////////////////////////////////////////////////////////////
-PDB_Country::PDB_Country(TQWidget *tqparent) : TQWidget(tqparent) {
+PDB_Country::PDB_Country(TQWidget *parent) : TQWidget(parent) {
TQLabel *l = new TQLabel(i18n("Select the location where you plan to use this\n"
"account from the list below. If your country or\n"
"location is not listed, you have to create the\n"
@@ -251,7 +251,7 @@ PDB_Country::~PDB_Country()
}
void PDB_Country::selectionChanged(int idx) {
// TQWizard *wizard = (TQWizard *)tqparent(); Why doesn't this work ?
ProviderDB::wiz->setNextEnabled(this, (idx != -1));
}
@@ -259,7 +259,7 @@ void PDB_Country::selectionChanged(int idx) {
/////////////////////////////////////////////////////////////////////////////
//
/////////////////////////////////////////////////////////////////////////////
-PDB_Provider::PDB_Provider(TQWidget *tqparent) : TQWidget(tqparent) {
+PDB_Provider::PDB_Provider(TQWidget *parent) : TQWidget(parent) {
TQVBoxLayout *tl = new TQVBoxLayout(this, 10, 10);
TQLabel *l = new TQLabel(i18n("Select your Internet Service Provider (ISP) from\n"
"the list below. If the ISP is not in this list,\n"
@@ -334,7 +334,7 @@ TQString PDB_Provider::getDir() {
/////////////////////////////////////////////////////////////////////////////
//
/////////////////////////////////////////////////////////////////////////////
-PDB_UserInfo::PDB_UserInfo(TQWidget *tqparent) : TQWidget(tqparent) {
+PDB_UserInfo::PDB_UserInfo(TQWidget *parent) : TQWidget(parent) {
TQVBoxLayout *tl = new TQVBoxLayout(this, 10, 10);
TQLabel *l = new TQLabel(i18n("To log on to your ISP, kppp needs the username\n"
"and the password you got from your ISP. Type\n"
@@ -388,7 +388,7 @@ void PDB_UserInfo::activate() {
/////////////////////////////////////////////////////////////////////////////
//
/////////////////////////////////////////////////////////////////////////////
-PDB_DialPrefix::PDB_DialPrefix(TQWidget *tqparent) : TQWidget(tqparent) {
+PDB_DialPrefix::PDB_DialPrefix(TQWidget *parent) : TQWidget(parent) {
TQVBoxLayout *tl = new TQVBoxLayout(this, 10, 10);
TQLabel *l = new TQLabel(i18n("If you need a special dial prefix (e.g. if you\n"
"are using a telephone switch) you can specify\n"
@@ -424,7 +424,7 @@ void PDB_DialPrefix::activate() {
/////////////////////////////////////////////////////////////////////////////
//
/////////////////////////////////////////////////////////////////////////////
-PDB_Finished::PDB_Finished(TQWidget *tqparent) : TQWidget(tqparent) {
+PDB_Finished::PDB_Finished(TQWidget *parent) : TQWidget(parent) {
TQVBoxLayout *tl = new TQVBoxLayout(this, 10, 10);
TQLabel *l = new TQLabel(i18n("Finished!\n\n"
"A new account has been created. Click \"Finish\" to\n"
@@ -251,7 +251,7 @@ PDB_Country::~PDB_Country()
}
void PDB_Country::selectionChanged(int idx) {
- // TQWizard *wizard = (TQWizard *)tqparent(); Why doesn't this work ?
+ // TQWizard *wizard = (TQWizard *)parent(); Why doesn't this work ?
ProviderDB::wiz->setNextEnabled(this, (idx != -1));
}